function [pte, ve, ue, gpe, vpe] = pt_test(pt, idlist, audiodir, audioext, gtdir, gtext, ptdir)
% [pte, ve, ue, gpe, vpe] = pt_test(pt, idlist, audiodir, audioext,gtdir, gtext, ptdir)
%    Run a pitch tracker over some examples, and score the result.
%    Inputs:
%      pt       - stem of pitch tracker; will run 'ptrack_'<pt>
%      idlist   - list of file IDs
%      audiodir
%      audioext - soundfiles to pitch track will be <audiodir>/<id><audioext>
%      gtdir
%      gtext    - reference pitch tracks are read from <gtdir>/<id><gtext>
%      ptdir    - pitch tracking results will be written to <ptdir>/<id>'-'<pt>'.txt'
%    Outputs (same as output of pt_eval):
%      pte      - pitch tracking error; simple mean of ve and ue
%      ve       - voicing error: proportion of ground-truth voiced frames incorrect
%      ue       - unvoiced error: proportion of ground-truth unvoiced frames incorrect
%      gpe      - gross pitch error: agreement on frames voiced in both ref & pt
%      vpe      - proportion of true-voiced frames where pt reports a pitch, but it's wrong
% 2013-08-24 Dan Ellis dpwe@ee.columbia.edu

if nargin < 6; gtext = '-gt.txt'; end

cleanup_pt = 0;
if nargin < 7; ptdir = tempname(); cleanup_pt = 1; end 

% build the output file list
mymkdir(ptdir);
ptoutlist = addprefixsuffix(idlist, [ptdir, '/'], ['-', pt, '.txt']);

% run the pitch tracker
dt = 0.010;
do_restore_f0 = 0;  % try to restore fundamental with nonlinearity?
verbose = 0;
ptfn = eval(['@ptrack_',pt]);
audfilelist = addprefixsuffix(idlist, [audiodir, '/'], audioext);
pt_wrap(audfilelist, ptoutlist, dt, ptfn, do_restore_f0, verbose);

gtfiles = addprefixsuffix(idlist, [gtdir, '/'], gtext);
thresh = 0.1;  % error tolerance (default)
[pte, ve, ue, gpe, vpe] = pt_eval(gtfiles, ptoutlist, thresh);

% print results
fprintf(1, 'Algo %9s: PTE=%4.1f%% (VE=%4.1f%% (VPE=%4.1f%%, VFR=%4.1f%%) UE=%4.1f%%) GPE=%4.1f%% \n', ...
        pt, 100*mean(pte), 100*mean(ve), 100*mean(vpe), ...
        100*mean(ve-vpe), 100*mean(ue), 100*mean(gpe));

if cleanup_pt
  % Remove PT outputs if we put them in a temporary directory
  system(['rm -r ', ptdir]);
end
