function [t,f0,pvx] = ptrack_yaapt(d,sr)
% [t,f0,pvx] = ptrack_yaapt(d,sr)
%    Run the yaapt pitch tracker on the waveform d (at sampling
%    frequency sr).
%    Returns three 1D vectors.  
%      t is the sample times at which pitches are estimated 
%          (typically uniformly spaced every 0.010 sec).  
%      f0 is the corresponding pitch value in Hz (which can be 
%          zero for unvoiced frames). 
%      pvx is the corresponding probability of voicing for each
%          frame (between 0 and 1).  Generally, a threshold of 0.5
%          is the best guess for actual voiced-unvoiced threshold.
%    This is supposed to be a generic framework for pitch trackers,
%    but in this case we'll run yaapt
% 2013-02-11 Dan Ellis dpwe@ee.columbia.edu

if ~isdeployed() && exist('yaapt','file') ~= 2
  addpath('yaapt')
end

% Chop up the soundfiles
%maxdur = 60;
%olap = 2;

maxdur = 60;
olap = 2;

% Do the time calculation in integer samples, to keep things clean
maxdursamp = round(maxdur*sr);
olapsamp = (olap*sr);

cuts = ceil(length(d)/maxdursamp);

t = [];
f0 = [];

xtime = -0.1;

for cut = 1:cuts

  % segment out part of the audio
  tstartsamp = (cut-1)*maxdursamp;
  tendsamp = min(cut*maxdursamp + olapsamp, length(d));
  dr = d(tstartsamp + [1:(tendsamp-tstartsamp)]);
  
  % run the pitch tracker
  [f0r, nfr, thopr] = yaapt(dr,sr);
  tr = tstartsamp/sr + (thopr/1000) * [0:(nfr-1)];
  
  % insert into the results
  keepold = find(t <= xtime);
  keepnew = find(tr > xtime);
  f0 = [f0(keepold),f0r(keepnew)];
  t =  [t(keepold),tr(keepnew)];

  % for next time around
  xtime = round(tendsamp - olapsamp/2)/sr;
  %disp(sprintf('xtime = %.1f', xtime));
end


% no extra info on voicing
pvx = double(f0>0);
