function [peaklocations,peakvalues,maxpeaklocations,maxpeakvalues] = getpeaks(x, lags, thrs)
%
%
% Finding the magnitudes and locations of peaks in correlation sequence
%
% kslee@ee.columbia.edu, 6/24/2005
% [2011-05-07] Byung Suk Lee bsl@ee.columbia.edu
%
if nargin < 3
    thrs = -999;
end

[nchs npts] = size(x);

oldway = 0;

if oldway

  nwin = 3;
  win = (-nwin:nwin);
  maxpeaklocations = zeros(nchs,1);
  maxpeakvalues = zeros(nchs,1);
  peaklocations = zeros(nchs,1);
  peakvalues = zeros(nchs,1);

  for ch = 1:nchs
      xx = x(ch,:);

      % Smoothing data and group delay compensation   
      %B = ones(1,nwin)/nwin;
      %A = 1;
      %gd = grpdelay(B,A,1024);
      %gd = floor(gd(1));    
      %sx = filter(B,A,[xx,zeros(1,gd)]);
      %sx = sx(gd+1:end);

      % Calculating the gradient for searching peak's locations
  %     dx = gradient(xx);
      % if input is a vector, diff & gradient do the same job in less time
      dx = diff(xx);

      % Distortion compensation due to filtering
      dx(1:2) = dx(3);
      dx(end-1:end) = dx(end-2);

      % Finding the possible location of peaks 
      px = find(diff(sign(dx)) == -2);

      % Finding the exact location of peaks by grid search
      maxvalue = -10000;
      if ~isempty(px)
          for i = 1:length(px)
              local_px = win + px(i);
              local_px = local_px(local_px > 0); 
              local_xx = xx(min(local_px,npts));
              [~,dmy2] = max(local_xx);
              peaklocations(ch,i) = lags(local_px(dmy2));
              peakvalues(ch,i) = xx(local_px(dmy2));

              % Finding maximum value and corresponding location
              if peakvalues(ch,i) > maxvalue
                  maxvalue = peakvalues(ch,i);
                  maxpeaklocations(ch) = peaklocations(ch,i);
                  maxpeakvalues(ch) = peakvalues(ch,i);
              end 
          end
      end

      decm = (peakvalues(ch,:) > thrs);

      peakvalues(ch,:) = sort(peakvalues(ch,:).*decm,'descend');
      peaklocations(ch,:) = sort(peaklocations(ch,:).*decm,'descend');

      if 0
          plot(lags,xx,'b-o');
          hold on;
          plot(lags,dx,'g-+');
          hold on;
          plot(peaklocations(ch,find(peaklocations(ch,:)>0)),peakvalues(ch,find(peaklocations(ch,:)>0)),'r-*');
          hold off;
          pause;
      end

  end 

else
  % new way
  
  peaklocations = zeros(nchs, npts);
  peakvalues = zeros(nchs, npts);
  maxpeaklocations = zeros(nchs, 1);
  maxpeakvalues = zeros(nchs, 1);

  ncol = 0;
  
%  for i = 1:nchs
%    [pks,lcs] = myfindpeaks(x(i,lags));
%    npks = length(pks);
%    peaklocations(i, 1:npks) = fliplr(lcs);
%    peakvalues(i, 1:npks) = fliplr(pks);
%    [pp,xx] = max(pks);
%    maxpeaklocations(i) = lcs(xx);
%    maxpeakvalues(i) = pp;
%    ncol = max(ncol, npks);
%  end

  % extensively hacked to avoid the nchs loop
  % dpwe@ee.columbia.edu 2013-02-07

  % mask of local maxima values across all rows
  lm = (x >= [zeros(nchs,1),x(:,1:end-1)]) & (x>[x(:,2:end),zeros(nchs,1)]);
  % don't allow first or last values
  lm(:,[1 end]) = 0;
  
  % quickly extract largest values and their positions in each row
  [maxpeakvalues,maxpeaklocations] = max(lm.*x, [], 2);
  
  % build a list of all the peak indices, padded with zeros, sorted
  % descending (this is what the original function did)
  ix = repmat([1:npts],nchs,1);
  [peaklocations,xx] = sort(ix.*lm, 2, 'descend');
  % figure out the corresponding values by building the flat-vector
  % indices corresponding to the indices in each row of xx
  xix = (xx-1)*nchs + repmat([1:nchs]',1,npts);
  % make sure all non-peak values read as zero
  xz = x.*lm;
  % read them out
  peakvalues(:) = xz(xix(:));
  
  % remove columns off end that are all zero
  % the longest row is the maximum number of 1s in a row of lm
  ncol = max(sum(lm,2));
  peaklocations = peaklocations(:, 1:ncol);
  peakvalues = peakvalues(:, 1:ncol);

end


%%%%%%%%%%%%%%%%%%%
%function [p,l] = myfindpeaks(x)
%lm = ( (x>=[0,x(1:end-1)]) & (x>[x(2:end),0]) );
%lm([1 end]) = 0;
%l = find(lm);
%p = x(l);


