function [lptable,uftable] = make_lptable(lags,centralfreq,sr)
%% make a look-up table for the laplacian and the uniform distributions
%
% [2011-05-07] Byung Suk Lee bsl@ee.columbia.edu

nchs = length(centralfreq);
nlags = length(lags);
distparm1 = 1.21 - 0.011*[1:nchs]; 

% uniform distribution
euftable = zeros(nchs,nlags);
uftable = zeros(nchs,nlags);
for c = 1:nchs
    euftable(c,:) = 0.0164*uniformdist(sr, centralfreq(c), 'lowfreq', nlags)*ones(1,nlags);
    uftable(c,:) = log(euftable(c,:)) + 4;
end

% laplacian distribution
lptable = zeros(nlags,nchs,nlags);
for peak = 1:length(lags)
    relativetimelags = lags - peak;
    % for channels
    for c = 1:nchs
    lptable(peak,c,:) = log(0.9836*laplaciandist(relativetimelags, distparm1(c)) ... 
            + euftable(c,:)) + 4;
    end
end


function L = laplaciandist(relativetimelags, distparm)
L = exp(-abs(relativetimelags)/distparm)/(distparm);
L = L/sum(L);


function U = uniformdist(sr, centralfreq, chtype, nlags)
if strcmp(chtype,'lowfreq')
    U = centralfreq/sr;
else
    U = 1/nlags;
end
